.. Matter Data Objects documentation master file, created by
   sphinx-quickstart on Tue Oct  6 12:45:53 2009.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Matter Data Objects
=================================================

Contents:

.. toctree::
   :maxdepth: 2

   overview
   tutorial
   api

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

